==> knt_ui-1.2.0.tar.gz: lib/src/widget/knt_progress_bar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import '../../generated/colors.gen.dart';
import 'knt_expandable_widget.dart';

const _animationDuration = Duration(milliseconds: 400);

class KntFullScreenInverseProgressBar extends StatelessWidget {
  final bool loadingAtFirst;

  const KntFullScreenInverseProgressBar({
    Key? key,
    this.loadingAtFirst = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return KntFullScreenProgressBar(
      loadingAtFirst: loadingAtFirst,
      progressColor: Colors.white,
      backgroundColor: Colors.black54,
    );
  }
}

class KntFullScreenProgressBar extends StatefulWidget {
  final bool loadingAtFirst;
  final Color? progressColor;
  final Color? backgroundColor;

  const KntFullScreenProgressBar({
    Key? key,
    this.loadingAtFirst = false,
    this.progressColor,
    this.backgroundColor,
  }) : super(key: key);

  @override
  _KntFullScreenProgressBarState createState() =>
      _KntFullScreenProgressBarState();
}

class _KntFullScreenProgressBarState extends State<KntFullScreenProgressBar> {
  late bool _loading;

  @override
  void initState() {
    super.initState();
    _initData();
  }

  @override
  void didUpdateWidget(covariant KntFullScreenProgressBar oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_loading != widget.loadingAtFirst) {
      setState(_initData);
    }
  }

  void _initData() {
    _loading = widget.loadingAtFirst;
  }

  @override
  Widget build(BuildContext context) {
    return KntExpandableWidget(
      expandedAtFirst: _loading,
      duration: _animationDuration,
      child: Container(
        width: 1.sw,
        height: 1.sh,
        decoration: BoxDecoration(
          color: widget.backgroundColor ?? Colors.transparent,
        ),
        child: KntProgressBar(
          color: widget.progressColor ?? ColorName.jungleGreen,
        ),
      ),
    );
  }
}

class KntProgressBar extends StatelessWidget {
  final Color? color;

  const KntProgressBar({
    Key? key,
    this.color,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: SpinKitCircle(
        size: 48.w,
        color: color ?? ColorName.jungleGreen,
      ),
    );
  }
}

==> knt_ui-1.3.0.tar.gz: lib/src/widget/knt_progress_bar.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_spinkit/flutter_spinkit.dart';

import '../config.dart';
import 'knt_expandable_widget.dart';

const _animationDuration = Duration(milliseconds: 400);

class KntFullScreenInverseProgressBar extends StatelessWidget {
  final bool loadingAtFirst;

  const KntFullScreenInverseProgressBar({
    Key? key,
    this.loadingAtFirst = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return KntFullScreenProgressBar(
      loadingAtFirst: loadingAtFirst,
      progressColor: Colors.white,
      backgroundColor: Colors.black54,
    );
  }
}

class KntFullScreenProgressBar extends StatefulWidget {
  final bool loadingAtFirst;
  final Color? progressColor;
  final Color? backgroundColor;

  const KntFullScreenProgressBar({
    Key? key,
    this.loadingAtFirst = false,
    this.progressColor,
    this.backgroundColor,
  }) : super(key: key);

  @override
  _KntFullScreenProgressBarState createState() =>
      _KntFullScreenProgressBarState();
}

class _KntFullScreenProgressBarState extends State<KntFullScreenProgressBar> {
  late bool _loading;

  @override
  void initState() {
    super.initState();
    _initData();
  }

  @override
  void didUpdateWidget(covariant KntFullScreenProgressBar oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_loading != widget.loadingAtFirst) {
      setState(_initData);
    }
  }

  void _initData() {
    _loading = widget.loadingAtFirst;
  }

  @override
  Widget build(BuildContext context) {
    return KntExpandableWidget(
      expandedAtFirst: _loading,
      duration: _animationDuration,
      child: Container(
        width: 1.sw,
        height: 1.sh,
        decoration: BoxDecoration(
          color: widget.backgroundColor ?? Colors.transparent,
        ),
        child: KntProgressBar(
          color: widget.progressColor ?? sharedConfig.primaryColor,
        ),
      ),
    );
  }
}

class KntProgressBar extends StatelessWidget {
  final Color? color;

  const KntProgressBar({
    Key? key,
    this.color,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Center(
      child: SpinKitCircle(
        size: 48.w,
        color: color ?? sharedConfig.primaryColor,
      ),
    );
  }
}
